==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/s3control/kotlin/outputs/StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryption.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3control.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property sseKms SSE-KMS encryption. See SSE KMS below for more details.
 * @property sseS3s SSE-S3 encryption. An empty configuration block `{}` should be used.
 */
public data class
StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryption(
    public val sseKms:
    StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryptionSseKms? =
        null,
    public val sseS3s:
    List<StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryptionSseS3>? =
        null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.s3control.outputs.StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryption):
            StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryption =
            StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryption(
                sseKms = javaType.sseKms().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.s3control.kotlin.outputs.StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryptionSseKms.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                sseS3s = javaType.sseS3s().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.s3control.kotlin.outputs.StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryptionSseS3.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/s3control/kotlin/outputs/StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryption.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3control.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property sseKms SSE-KMS encryption. See SSE KMS below for more details.
 * @property sseS3s SSE-S3 encryption. An empty configuration block `{}` should be used.
 */
public data class
StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryption(
    public val sseKms: StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryptionSseKms? =
        null,
    public val sseS3s: List<StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryptionSseS3>? =
        null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.s3control.outputs.StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryption): StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryption =
            StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryption(
                sseKms = javaType.sseKms().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.s3control.kotlin.outputs.StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryptionSseKms.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                sseS3s = javaType.sseS3s().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.s3control.kotlin.outputs.StorageLensConfigurationStorageLensConfigurationDataExportS3BucketDestinationEncryptionSseS3.Companion.toKotlin(args0)
                    })
                }),
            )
    }
}
